@@ -27,12 +27,11 @@
 # include "container.h"
 # include "status.h"
 
-typedef int (*container_entrypoint_t) (void *args, const char *notify_socket,
+typedef int (*container_entrypoint_t) (void *args, char *notify_socket,
                                        int sync_socket,
                                        libcrun_error_t *err);
 
 pid_t libcrun_run_linux_container (libcrun_container_t *container,
-                                   int detach,
                                    container_entrypoint_t entrypoint,
                                    void *args,
                                    int *sync_socket_out,
@@ -69,4 +68,8 @@ int libcrun_container_restore_linux (libcrun_container_status_t *status,
                                      libcrun_container_t *container,
                                      libcrun_checkpoint_restore_t *cr_options,
                                      libcrun_error_t *err);
+
+int libcrun_find_namespace (const char *name);
+char *libcrun_get_external_descriptors (libcrun_container_t *container);
+int libcrun_container_setgroups (libcrun_container_t *container, libcrun_error_t *err);
 #endif
